@@ -151,7 +151,8 @@ Craig Andrews
 
 #define BYTE1 unsigned char
 #define BYTE2 unsigned short
-#define BYTE4 unsigned long
+
+#define BYTE4 unsigned int
 
 #ifdef __mac_os
 #define bool Boolean
@@ -2959,14 +2960,14 @@ int rnd(int range)
     static bool flag=FALSE;
 
     if(flag==FALSE) {
-#if defined(DOS) || defined(__mac_os) || defined(_MSC_VER) || defined(__MINGW32_VERSION)
+#if defined(DOS) || defined(__mac_os) || defined(_MSC_VER) || defined(__MINGW32_VERSION) || defined(WIN32)
 	srand(time(NULL));
 #else
 	srand48(time(NULL));
 #endif
     }
     flag=TRUE;
-#if defined(DOS) || defined(__mac_os) || defined(_MSC_VER) || defined(__MINGW32_VERSION)
+#if defined(DOS) || defined(__mac_os) || defined(_MSC_VER) || defined(__MINGW32_VERSION) || defined(WIN32)
     return(rand()%range);
 #else
     return(floor(drand48()*(double)(range)));
